ObjectStore

Trait ObjectStore 

pub trait ObjectStore: Send + Sync {
    // Required methods
    fn load(&self, object_id: &str) -> Result<Vec<u8>, ObjectStoreError>;
    fn save(&self, bytes: &[u8]) -> Result<String, ObjectStoreError>;
}
Policy-blind immutable payload storage supplied by the integrating server.

Published executables do not use this store. It is used only to resolve ordered call inputs and save ordered call outputs.

Required Methods

fn load(&self, object_id: &str) -> Result<Vec<u8>, ObjectStoreError>

fn save(&self, bytes: &[u8]) -> Result<String, ObjectStoreError>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors